@@ -28,6 +28,7 @@ from .literals import (
     PrincipalTypeType,
     ResourceSortTypeType,
     ResourceStateTypeType,
+    SearchQueryScopeTypeType,
     SubscriptionProtocolTypeType,
     UserFilterTypeType,
     UserSortTypeType,
@@ -43,6 +44,7 @@ from .paginator import (
     DescribeResourcePermissionsPaginator,
     DescribeRootFoldersPaginator,
     DescribeUsersPaginator,
+    SearchResourcesPaginator,
 )
 from .type_defs import (
     ActivateUserResponseTypeDef,
@@ -61,6 +63,7 @@ from .type_defs import (
     DescribeRootFoldersResponseTypeDef,
     DescribeUsersResponseTypeDef,
     EmptyResponseMetadataTypeDef,
+    FiltersTypeDef,
     GetCurrentUserResponseTypeDef,
     GetDocumentPathResponseTypeDef,
     GetDocumentResponseTypeDef,
@@ -70,6 +73,8 @@ from .type_defs import (
     GetResourcesResponseTypeDef,
     InitiateDocumentVersionUploadResponseTypeDef,
     NotificationOptionsTypeDef,
+    SearchResourcesResponseTypeDef,
+    SearchSortResultTypeDef,
     SharePrincipalTypeDef,
     StorageRuleTypeTypeDef,
     UpdateUserResponseTypeDef,
@@ -338,7 +343,7 @@ class WorkDocsClient(BaseClient):
         AuthenticationToken: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
-        Deletes a version of an Amazon WorkDocs document.
+        Deletes a specific version of a document.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.delete_document_version)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_document_version)
@@ -710,6 +715,27 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#restore_document_versions)
         """
 
+    def search_resources(
+        self,
+        *,
+        AuthenticationToken: str = ...,
+        QueryText: str = ...,
+        QueryScopes: Sequence[SearchQueryScopeTypeType] = ...,
+        OrganizationId: str = ...,
+        AdditionalResponseFields: Sequence[Literal["WEBURL"]] = ...,
+        Filters: FiltersTypeDef = ...,
+        OrderBy: Sequence[SearchSortResultTypeDef] = ...,
+        Limit: int = ...,
+        Marker: str = ...
+    ) -> SearchResourcesResponseTypeDef:
+        """
+        Searches metadata and the content of folders, documents, document versions, and
+        comments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.search_resources)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#search_resources)
+        """
+
     def update_document(
         self,
         *,
@@ -854,3 +880,12 @@ class WorkDocsClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.get_paginator)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#get_paginator)
         """
+
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["search_resources"]
+    ) -> SearchResourcesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#get_paginator)
+        """
