@@ -19,6 +19,7 @@ Usage::
         DescribeResourcePermissionsPaginator,
         DescribeRootFoldersPaginator,
         DescribeUsersPaginator,
+        SearchResourcesPaginator,
     )
 
     session = Session()
@@ -33,10 +34,12 @@ Usage::
     describe_resource_permissions_paginator: DescribeResourcePermissionsPaginator = client.get_paginator("describe_resource_permissions")
     describe_root_folders_paginator: DescribeRootFoldersPaginator = client.get_paginator("describe_root_folders")
     describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
+    search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
     ```
 """
+import sys
 from datetime import datetime
-from typing import Generic, Iterator, TypeVar, Union
+from typing import Generic, Iterator, Sequence, TypeVar, Union
 
 from botocore.paginate import PageIterator, Paginator
 
@@ -44,6 +47,7 @@ from .literals import (
     FolderContentTypeType,
     OrderTypeType,
     ResourceSortTypeType,
+    SearchQueryScopeTypeType,
     UserFilterTypeType,
     UserSortTypeType,
 )
@@ -57,9 +61,18 @@ from .type_defs import (
     DescribeResourcePermissionsResponseTypeDef,
     DescribeRootFoldersResponseTypeDef,
     DescribeUsersResponseTypeDef,
+    FiltersTypeDef,
     PaginatorConfigTypeDef,
+    SearchResourcesResponseTypeDef,
+    SearchSortResultTypeDef,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = (
     "DescribeActivitiesPaginator",
     "DescribeCommentsPaginator",
@@ -70,6 +83,7 @@ __all__ = (
     "DescribeResourcePermissionsPaginator",
     "DescribeRootFoldersPaginator",
     "DescribeUsersPaginator",
+    "SearchResourcesPaginator",
 )
 
 
@@ -265,3 +279,27 @@ class DescribeUsersPaginator(Paginator):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers.paginate)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators/#describeuserspaginator)
         """
+
+
+class SearchResourcesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Paginator.SearchResources)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators/#searchresourcespaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        AuthenticationToken: str = ...,
+        QueryText: str = ...,
+        QueryScopes: Sequence[SearchQueryScopeTypeType] = ...,
+        OrganizationId: str = ...,
+        AdditionalResponseFields: Sequence[Literal["WEBURL"]] = ...,
+        Filters: FiltersTypeDef = ...,
+        OrderBy: Sequence[SearchSortResultTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[SearchResourcesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Paginator.SearchResources.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators/#searchresourcespaginator)
+        """
