@@ -20,19 +20,28 @@ from .literals import (
     BooleanEnumTypeType,
     CommentStatusTypeType,
     CommentVisibilityTypeType,
+    ContentCategoryTypeType,
     DocumentSourceTypeType,
     DocumentStatusTypeType,
     DocumentThumbnailTypeType,
     FolderContentTypeType,
+    LanguageCodeTypeType,
     LocaleTypeType,
+    OrderByFieldTypeType,
     OrderTypeType,
+    PrincipalRoleTypeType,
     PrincipalTypeType,
     ResourceSortTypeType,
     ResourceStateTypeType,
     ResourceTypeType,
+    ResponseItemTypeType,
     RolePermissionTypeType,
     RoleTypeType,
+    SearchCollectionTypeType,
+    SearchQueryScopeTypeType,
+    SearchResourceTypeType,
     ShareStatusTypeType,
+    SortOrderType,
     StorageTypeType,
     SubscriptionProtocolTypeType,
     UserFilterTypeType,
@@ -67,6 +76,7 @@ __all__ = (
     "CreateNotificationSubscriptionRequestRequestTypeDef",
     "SubscriptionTypeDef",
     "StorageRuleTypeTypeDef",
+    "DateRangeTypeTypeDef",
     "DeactivateUserRequestRequestTypeDef",
     "DeleteCommentRequestRequestTypeDef",
     "DeleteCustomMetadataRequestRequestTypeDef",
@@ -89,6 +99,8 @@ __all__ = (
     "DescribeResourcePermissionsRequestRequestTypeDef",
     "DescribeRootFoldersRequestRequestTypeDef",
     "DescribeUsersRequestRequestTypeDef",
+    "LongRangeTypeTypeDef",
+    "SearchPrincipalTypeTypeDef",
     "GetCurrentUserRequestRequestTypeDef",
     "GetDocumentPathRequestRequestTypeDef",
     "GetDocumentRequestRequestTypeDef",
@@ -103,6 +115,7 @@ __all__ = (
     "RemoveResourcePermissionRequestRequestTypeDef",
     "ResourcePathComponentTypeDef",
     "RestoreDocumentVersionsRequestRequestTypeDef",
+    "SearchSortResultTypeDef",
     "UpdateDocumentRequestRequestTypeDef",
     "UpdateDocumentVersionRequestRequestTypeDef",
     "UpdateFolderRequestRequestTypeDef",
@@ -132,6 +145,7 @@ __all__ = (
     "GetDocumentVersionResponseTypeDef",
     "DescribeGroupsResponseTypeDef",
     "ParticipantsTypeDef",
+    "FiltersTypeDef",
     "PrincipalTypeDef",
     "ResourcePathTypeDef",
     "UserTypeDef",
@@ -139,6 +153,8 @@ __all__ = (
     "GetDocumentResponseTypeDef",
     "GetResourcesResponseTypeDef",
     "InitiateDocumentVersionUploadResponseTypeDef",
+    "SearchResourcesRequestRequestTypeDef",
+    "SearchResourcesRequestSearchResourcesPaginateTypeDef",
     "DescribeResourcePermissionsResponseTypeDef",
     "GetDocumentPathResponseTypeDef",
     "GetFolderPathResponseTypeDef",
@@ -150,9 +166,11 @@ __all__ = (
     "GetCurrentUserResponseTypeDef",
     "UpdateUserResponseTypeDef",
     "ActivityTypeDef",
+    "ResponseItemTypeDef",
     "CreateCommentResponseTypeDef",
     "DescribeCommentsResponseTypeDef",
     "DescribeActivitiesResponseTypeDef",
+    "SearchResourcesResponseTypeDef",
 )
 
 _RequiredAbortDocumentVersionUploadRequestRequestTypeDef = TypedDict(
@@ -395,6 +413,15 @@ StorageRuleTypeTypeDef = TypedDict(
     total=False,
 )
 
+DateRangeTypeTypeDef = TypedDict(
+    "DateRangeTypeTypeDef",
+    {
+        "StartValue": Union[datetime, str],
+        "EndValue": Union[datetime, str],
+    },
+    total=False,
+)
+
 _RequiredDeactivateUserRequestRequestTypeDef = TypedDict(
     "_RequiredDeactivateUserRequestRequestTypeDef",
     {
@@ -850,6 +877,36 @@ DescribeUsersRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
+LongRangeTypeTypeDef = TypedDict(
+    "LongRangeTypeTypeDef",
+    {
+        "StartValue": int,
+        "EndValue": int,
+    },
+    total=False,
+)
+
+_RequiredSearchPrincipalTypeTypeDef = TypedDict(
+    "_RequiredSearchPrincipalTypeTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalSearchPrincipalTypeTypeDef = TypedDict(
+    "_OptionalSearchPrincipalTypeTypeDef",
+    {
+        "Roles": Sequence[PrincipalRoleTypeType],
+    },
+    total=False,
+)
+
+
+class SearchPrincipalTypeTypeDef(
+    _RequiredSearchPrincipalTypeTypeDef, _OptionalSearchPrincipalTypeTypeDef
+):
+    pass
+
+
 GetCurrentUserRequestRequestTypeDef = TypedDict(
     "GetCurrentUserRequestRequestTypeDef",
     {
@@ -1096,6 +1153,15 @@ class RestoreDocumentVersionsRequestRequestTypeDef(
     pass
 
 
+SearchSortResultTypeDef = TypedDict(
+    "SearchSortResultTypeDef",
+    {
+        "Field": OrderByFieldTypeType,
+        "Order": SortOrderType,
+    },
+    total=False,
+)
+
 _RequiredUpdateDocumentRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateDocumentRequestRequestTypeDef",
     {
@@ -1580,6 +1646,23 @@ ParticipantsTypeDef = TypedDict(
     total=False,
 )
 
+FiltersTypeDef = TypedDict(
+    "FiltersTypeDef",
+    {
+        "TextLocales": Sequence[LanguageCodeTypeType],
+        "ContentCategories": Sequence[ContentCategoryTypeType],
+        "ResourceTypes": Sequence[SearchResourceTypeType],
+        "Labels": Sequence[str],
+        "Principals": Sequence[SearchPrincipalTypeTypeDef],
+        "AncestorIds": Sequence[str],
+        "SearchCollectionTypes": Sequence[SearchCollectionTypeType],
+        "SizeRange": LongRangeTypeTypeDef,
+        "CreatedRange": DateRangeTypeTypeDef,
+        "ModifiedRange": DateRangeTypeTypeDef,
+    },
+    total=False,
+)
+
 PrincipalTypeDef = TypedDict(
     "PrincipalTypeDef",
     {
@@ -1658,6 +1741,37 @@ InitiateDocumentVersionUploadResponseTypeDef = TypedDict(
     },
 )
 
+SearchResourcesRequestRequestTypeDef = TypedDict(
+    "SearchResourcesRequestRequestTypeDef",
+    {
+        "AuthenticationToken": str,
+        "QueryText": str,
+        "QueryScopes": Sequence[SearchQueryScopeTypeType],
+        "OrganizationId": str,
+        "AdditionalResponseFields": Sequence[Literal["WEBURL"]],
+        "Filters": FiltersTypeDef,
+        "OrderBy": Sequence[SearchSortResultTypeDef],
+        "Limit": int,
+        "Marker": str,
+    },
+    total=False,
+)
+
+SearchResourcesRequestSearchResourcesPaginateTypeDef = TypedDict(
+    "SearchResourcesRequestSearchResourcesPaginateTypeDef",
+    {
+        "AuthenticationToken": str,
+        "QueryText": str,
+        "QueryScopes": Sequence[SearchQueryScopeTypeType],
+        "OrganizationId": str,
+        "AdditionalResponseFields": Sequence[Literal["WEBURL"]],
+        "Filters": FiltersTypeDef,
+        "OrderBy": Sequence[SearchSortResultTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
 DescribeResourcePermissionsResponseTypeDef = TypedDict(
     "DescribeResourcePermissionsResponseTypeDef",
     {
@@ -1699,6 +1813,7 @@ CommentMetadataTypeDef = TypedDict(
         "CreatedTimestamp": datetime,
         "CommentStatus": CommentStatusTypeType,
         "RecipientId": str,
+        "ContributorId": str,
     },
     total=False,
 )
@@ -1779,6 +1894,19 @@ ActivityTypeDef = TypedDict(
     total=False,
 )
 
+ResponseItemTypeDef = TypedDict(
+    "ResponseItemTypeDef",
+    {
+        "ResourceType": ResponseItemTypeType,
+        "WebUrl": str,
+        "DocumentMetadata": DocumentMetadataTypeDef,
+        "FolderMetadata": FolderMetadataTypeDef,
+        "CommentMetadata": CommentMetadataTypeDef,
+        "DocumentVersionMetadata": DocumentVersionMetadataTypeDef,
+    },
+    total=False,
+)
+
 CreateCommentResponseTypeDef = TypedDict(
     "CreateCommentResponseTypeDef",
     {
@@ -1804,3 +1932,12 @@ DescribeActivitiesResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+SearchResourcesResponseTypeDef = TypedDict(
+    "SearchResourcesResponseTypeDef",
+    {
+        "Items": List[ResponseItemTypeDef],
+        "Marker": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
